SystemOrganization addCategory: #Deli!
SystemOrganization addCategory: #'Deli-models'!
SystemOrganization addCategory: #'Deli-configuration'!
SystemOrganization addCategory: #'Deli-models-tests'!
SystemOrganization addCategory: #'Deli-frontend'!

SqsTestCase subclass: #DLDeliTestCase
	instanceVariableNames: 'semester lecture user membership group'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

DLDeliTestCase subclass: #DLDeadlineTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 11:34'!
fixture
	"We assume that creation through the orm works."

	semester := DLSemester new
		semesterName: 'Winter';
		year: 2009;
		save.
	
	lecture := DLLecture new
		lectureName: 'Softwaretechnik I';
		description: 'An introduction to techniques in software development';
		semester: semester;
		save.
	
	user := DLUser new
		userName: 'Sebastian';
		save.
	
	membership := DLLectureMembership new
		user: user;
		lecture: lecture;
		role: #student;
		save.

	group := DLGroup new
		groupName: 'Roundup porns';
		description: 'Roundup in awesome';
		lecture: lecture;
		users: ( {user} as: OrderedCollection );
		save.! !

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 11:37'!
setUp
	| session |
	super setUp.
	self fixture.
	session := SqsConnectionManager getInstance sessionForClass: DLLecture.
	session resetDatabase.
	"session beginTransaction."

! !

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 19:35'!
tearDown
	| session |
	super tearDown.
	
	"""session := SqsConnectionManager getInstance sessionForClass: DLLecture.
	session rollbackTransaction."""
! !

DLDeliTestCase subclass: #DLLectureMembershipTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLLectureMembershipTest methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 09:25'!
testUniqueMemberships
	| aNotAllowedMembership |
	aNotAllowedMembership := DLLectureMembership withLecture: lecture user: user role: #teacher.
	self assert: [ aNotAllowedMembership = nil] description: 'A second membership on the same person should not be created.'.
	
	membership destroy.
	membership := DLLectureMembership withLecture: lecture user: user role: #teacher.
	
	self assert: [ membership ~= nil ] description: 'A membership can be created after the other membership was deleted.'.
! !

DLDeliTestCase subclass: #DLLectureTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

DLDeliTestCase subclass: #DLSemesterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

WATask subclass: #DLRootTask
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLRootTask class methodsFor: 'testing' stamp: 'Marik 5/26/2009 13:30'!
canBeRoot

	^true! !

!DLRootTask methodsFor: 'processing' stamp: 'Marik 5/26/2009 13:33'!
go

	|loginAnswer|
	loginAnswer := self call: DLLoginComp new.
	loginAnswer
		ifNotNil: [
			self session login: loginAnswer.
			self call: DLDashComp new]! !

WASession subclass: #DLSession
	instanceVariableNames: 'user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
isLoggedIn

	^self user isNil not! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
login: aUser

	self user: aUser! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
logout

	self user: nil.! !

!DLSession methodsFor: 'accessing' stamp: 'Marik 5/20/2009 17:08'!
user

	^ user! !

!DLSession methodsFor: 'accessing' stamp: 'Marik 5/20/2009 17:08'!
user: anObject

	user := anObject.! !

WAComponent subclass: #DLDashComp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLDashComp methodsFor: 'rendering' stamp: 'Marik 5/20/2009 17:14'!
renderContentOn: html

	html 	heading: 'Dash';
			break;
			text: 'Willkommen ', self session user userName! !

WAComponent subclass: #DLLoginComp
	instanceVariableNames: 'userName password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 16:56'!
acceptUser

	|user|
	user := DLUser new.
	user userName: self userName.
	self 	clearUserData;
			answer: user! !

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:16'!
clearUserData

	self 	userName: nil;
			password: nil! !

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 16:56'!
denyUser

	self 	clearUserData;
			answer: nil! !

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 16:38'!
hashPassword: aPassword

	aPassword 	ifEmpty: [^0]
					ifNotEmpty: [^SecureHashAlgorithm new hashMessage: aPassword]! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
password

	^ password! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
password: anObject

	password := anObject.! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/20/2009 16:34'!
renderContentOn: html

	html 	heading: 'Login to the Deli System'.
			html 	form: [
			html 	table: [
					html 	tableRow: [self renderNameInputOn: html];
							tableRow: [self renderPasswordInputOn: html];
							tableRow: [self renderSubmitButtonOn: html]]].! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/20/2009 16:30'!
renderNameInputOn: html

	html 	tableData: [html text: 'Name: '];
			tableData: [html textInput on: #userName of: self]! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/20/2009 16:46'!
renderPasswordInputOn: html

	html 	tableData: [html text: 'Password: '];
			tableData: [html passwordInput on: #password of: self]

"password bisher plain, vielleicht sowas? callback: [:value | self password: (self hashPassword: value)]]"! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/20/2009 16:41'!
renderSubmitButtonOn: html

	html tableData: [html submitButton 	callback:[self validateLogin];
													text: 'Login']
! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
userName

	^ userName! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
userName: anObject

	userName := anObject.! !

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 16:51'!
validateLogin

	|loginChecker|
	loginChecker := HPILoginChecker new.
	(loginChecker checkLogin: self userName password: self password)
		ifTrue:[self acceptUser]
		ifFalse:[self denyUser]! !

SqsSearchInterface subclass: #DLDeadline
	instanceVariableNames: 'deadlineName description date'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
date

	^ date! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
date: anObject

	date := anObject.! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
deadlineName

	^ deadlineName! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
deadlineName: anObject

	deadlineName := anObject.! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
description

	^ description! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
description: anObject

	description := anObject.! !

SqsSearchInterface subclass: #DLGroup
	instanceVariableNames: 'groupName description lecture users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'description';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrGroupName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'group_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'groupName';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLecture
	^ SqsColumn new associatedClass: #DLLecture;
		 manuallyMaintained: false;
		 columnName: 'lecture_id';
		 sqlType: #integer;
		 objectClass: #DLLecture;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lecture';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUsers
	^ SqsCollectionDescription new manuallyMaintained: false;
		 collectionClass: #OrderedCollection;
		 tableName: 'dl_groups_users';
		 ownerColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'dl_group_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_groups';
				 updateActions: #();
				 deleteActions: (OrderedCollection new add: #CASCADE;
					 yourself);
				 referencingColumns: (Set new add: 'dl_group_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSOWNER;
			 yourself);
		 referenceColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'users_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_users';
				 updateActions: #();
				 deleteActions: #(#CASCADE );
				 referencingColumns: (Set new add: 'users_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSREF;
			 yourself);
		 maintainOrder: true;
		 simpleValues: false;
		 indexType: #integer;
		 referencedClass: #DLUser;
		 linkedVariable: 'users';
		 orderField: 'sqs_order_number';
		 yourself! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
description

	^ description! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
description: anObject

	description := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
groupName

	^ groupName! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
groupName: anObject

	groupName := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 12:00'!
initialize
	super initialize.
	self users: OrderedCollection new.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
lecture

	^ lecture! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
lecture: anObject

	lecture := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
users

	^ users! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
users: anObject

	users := anObject.! !

SqsSearchInterface subclass: #DLLecture
	instanceVariableNames: 'lectureName semester description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'description';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLectureName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'lecture_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lectureName';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrSemester
	^ SqsColumn new associatedClass: #DLSemester;
		 manuallyMaintained: false;
		 columnName: 'semester_id';
		 sqlType: #integer;
		 objectClass: #DLSemester;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'semester';
		 yourself! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
description

	^ description! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
description: anObject

	description := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
lectureName

	^ lectureName! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
lectureName: anObject

	lectureName := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
semester

	^ semester! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
semester: anObject

	semester := anObject.! !

SqsSearchInterface subclass: #DLLectureMembership
	instanceVariableNames: 'lecture user role'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLecture
	^ SqsColumn new associatedClass: #DLLecture;
		 manuallyMaintained: false;
		 columnName: 'lecture_id';
		 sqlType: #integer;
		 objectClass: #DLLecture;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lecture';
		 yourself! !

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrRole
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'role';
		 sqlType: #string;
		 objectClass: #ByteSymbol;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'role';
		 yourself! !

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUser
	^ SqsColumn new associatedClass: #DLUser;
		 manuallyMaintained: false;
		 columnName: 'user_id';
		 sqlType: #integer;
		 objectClass: #DLUser;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'user';
		 yourself! !

!DLLectureMembership class methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 09:20'!
withLecture: aLecture user: aUser role: aRole
	
	| memberships |
	memberships := 
	(SqsSearch for: self) detect: [:aMembership | (aMembership lecture = aLecture) & (aMembership user = aUser)] ifNone: [nil].
	
	memberships ifNotNil: [ ^ nil ].
	
	^ self new
		lecture: aLecture;
		user: aUser;
		role: aRole;
		save;
		yourself.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
lecture

	^ lecture! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
lecture: anObject

	lecture := anObject.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:05'!
role

	^ role! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:05'!
role: anObject

	role := anObject.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
user

	^ user! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
user: anObject

	user := anObject.! !

SqsSearchInterface subclass: #DLSemester
	instanceVariableNames: 'semesterName year'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLSemester class methodsFor: 'persistence-description' stamp: ''!
sqsDescrSemesterName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'semester_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_semesters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'semesterName';
		 yourself! !

!DLSemester class methodsFor: 'persistence-description' stamp: ''!
sqsDescrYear
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'year';
		 sqlType: #integer;
		 objectClass: #SmallInteger;
		 tableName: 'dl_semesters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'year';
		 yourself! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
semesterName

	^ semesterName! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
semesterName: anObject

	semesterName := anObject.! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
year

	^ year! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
year: anObject

	year := anObject.! !

SqsSearchInterface subclass: #DLUpdateModel
	instanceVariableNames: 'created updated'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLUpdateModel class methodsFor: 'persistence-description' stamp: ''!
sqsDescrCreated
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'created';
		 sqlType: #dateAndTime;
		 objectClass: #DateAndTime;
		 tableName: 'dl_update_models';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'created';
		 yourself! !

!DLUpdateModel class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUpdated
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'updated';
		 sqlType: #dateAndTime;
		 objectClass: #DateAndTime;
		 tableName: 'dl_update_models';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'updated';
		 yourself! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
created

	^ created! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
created: anObject

	created := anObject.! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:06'!
initialize
	self created: DateAndTime now.! !

!DLUpdateModel methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 19:06'!
save
	self updated: DateAndTime now.
	super save! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
updated

	^ updated! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
updated: anObject

	updated := anObject.! !

Object subclass: #DLUser
	instanceVariableNames: 'userName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLUser class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUserName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'user_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'wa_presenters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'userName';
		 yourself! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/26/2009 13:25'!
userName

	^ userName! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/26/2009 13:25'!
userName: anObject

	userName := anObject.! !

Object subclass: #Tutorials
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli'!

!Tutorials methodsFor: 'as yet unclassified' stamp: 'Marik 5/19/2009 17:41'!
HowToUseHPILogin

"
--> Load LDAPlayer v47 via SqueakMapPackageLoader
--> Load HPILogin class via Monticello from Repository http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/HPILogin

--> Use

hpi := HPILoginChecker new.
hpi checkLogin: 'surname.name' password: '******'"! !

SqsConfig subclass: #DeliSqsConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-configuration'!

!DeliSqsConfig class methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 16:13'!
connectionSpecification
	^ SqsMySQLConnectionSpecification 
		user: 'deli'
		password: ''
		database: 'deli'
		port: 3306
		host: 'localhost'! !
